abacusai.annotation — AbacusAI documentation

# abacusai.annotation

## Classes

`AbstractApiClass` |
`Annotation` | An Annotation Store Annotation

## Module Contents

class abacusai.annotation.AbstractApiClass(client, id)
  __eq__(other)

    Return self==value.

  _get_attribute_as_dict(attribute)

class abacusai.annotation.Annotation(client, annotationType=None, annotationValue=None, comments=None, metadata=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  An Annotation Store Annotation

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - annotationType (str) – A name determining the type of annotation and how to interpret the annotation value data, e.g. as a label, bounding box, etc.

    - annotationValue (dict) – JSON-compatible value of the annotation. The format of the value is determined by the annotation type.

    - comments (dict) – Comments about the annotation. This is a dictionary of feature name to the corresponding comment.

    - metadata (dict) – Metadata about the annotation.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict